@@ -5,6 +5,7 @@ from pilot.impl.pilotcompute_manager import PilotComputeService as MyPilotComput
 from pilot.impl.pilotdata_manager import PilotDataService as MyPilotDataService
 from pilot.impl.pilotdata_manager import DataUnit as MyDataUnit
 from pilot.impl.pilot_manager import ComputeDataService as MyComputeDataService
+from pilot.impl.pilot_manager import ComputeUnit as MyComputeUnit
 from pilot.api import State as MyState
 
 # define external-facing API
@@ -17,6 +18,9 @@ class PilotDataService(MyPilotDataService):
     pass
 
 
+class ComputeUnit(MyComputeUnit):
+    pass
+
 class DataUnit(MyDataUnit):
     pass
 
